@@ -2,7 +2,7 @@ package Plack::Request;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.9980';
+our $VERSION = '0.9981';
 $VERSION = eval $VERSION;
 
 use HTTP::Headers;
@@ -362,8 +362,8 @@ certainly possible but not recommended: it's like doing so with
 mod_perl's Apache::Request: yet too low level.
 
 If you're writing a web application, not a framework, then you're
-encouraged to use one of the web application frameworks that support
-PSGI, or see modules like L<HTTP::Engine> to provide higher level
+encouraged to use one of the web application frameworks that support PSGI (L<http://plackperl.org/#frameworks>),
+or see modules like L<HTTP::Engine> to provide higher level
 Request and Response API on top of PSGI.
 
 =head1 METHODS
